using TIAM.Entities.TransferDestinations;
using TIAMWebApp.Shared.Application.Models;
using TIAMWebApp.Shared.Application.Models.ClientSide.UI.WizardModels;

namespace TIAMWebApp.Shared.Application.Interfaces
{
    public interface ITransferDataService
    {
        Task<List<TransferDestination>> GetDestinationsAsync();
        Task<TransferDestination?> GetTransferDestinationbyCoordinatesAsync(string destinationId);
        Task<TransferDestination?> GetTransferDestinationbyAddressAsync(string destinationId);
        Task<TransferDestination?> CreateTransferDestination(TransferDestination model);

        Task<TransferDestination?> UpdateTransferDestination(TransferDestination model); 

        Task<TransferWizardModel?> CreateTransfer(TransferWizardModel model);
    }
}
